define(
//begin v1.x content
{
	"HKD_displayName": "Hongkongse dollar",
	"CNY_displayName": "Chinese yuan",
	"JPY_displayName": "Japanse yen",
	"JPY_symbol": "JP¥",
	"USD_displayName": "Amerikaanse dollar",
	"CAD_symbol": "C$",
	"GBP_displayName": "Brits pond",
	"CHF_displayName": "Zwitserse frank",
	"CNY_symbol": "CN¥",
	"EUR_displayName": "Euro",
	"GBP_symbol": "£",
	"CAD_displayName": "Canadese dollar",
	"USD_symbol": "US$",
	"EUR_symbol": "€",
	"AUD_displayName": "Australische dollar",
	"CHF_symbol": "CHF",
	"HKD_symbol": "HK$",
	"AUD_symbol": "AU$"
}
//end v1.x content
);